.. _templates:

#########
Templates
#########

.. toctree::
    :maxdepth: 1

    preprocess

    annotate

    get_markers

    classic

    cellpose

    ilastik_prep

    ilastik_output

    membrane_performance

    cellpose_train